@@ -3,7 +3,7 @@ use std::time::Duration;
 use async_std::task::sleep;
 
 #[mry::mry]
-#[derive(Default, PartialEq)]
+#[derive(Default)]
 struct Cat {
     name: String,
 }
@@ -17,13 +17,13 @@ impl Cat {
 }
 
 #[async_std::test]
-async fn meow_behaves() {
+async fn meow_returns_with() {
     let mut cat: Cat = Cat {
         name: "Tama".into(),
         ..Default::default()
     };
-    cat.mock_meow()
-        .behaves(|count| format!("Called with {}", count));
+    cat.mock_meow(2)
+        .returns_with(|count| format!("Called with {}", count));
 
     assert_eq!(cat.meow(2).await, "Called with 2".to_string());
 }
