@@ -1,5 +1,5 @@
 #[mry::mry]
-#[derive(Default, PartialEq)]
+#[derive(Default)]
 struct Cat<'a> {
     name: &'a str,
 }
@@ -12,12 +12,12 @@ impl<'a> Into<String> for Cat<'a> {
 }
 
 #[async_std::test]
-async fn meow_behaves() {
+async fn meow_returns_with() {
     let mut cat: Cat = Cat {
         name: "Tama".into(),
         ..Default::default()
     };
-    cat.mock_into().behaves(|| format!("Called"));
+    cat.mock_into().returns_with(|| format!("Called"));
 
     assert_eq!(<Cat as Into<String>>::into(cat), "Called".to_string());
 }
